@@ -63,7 +63,8 @@ class Image(BaseImage):
 
         super(Image, self).__init__(release, platform, instance_type, architecture, region, virtualization)
 
-        self.date = datetime.datetime.strptime(date, "%Y%m%d")
+        # Sometimes the date has ".1", so we need to remove it.
+        self.date = datetime.datetime.strptime(date.split('.', 1)[0], "%Y%m%d")
         self.stability = stability
         self.ami_id = ami_id
         self.aki_id = aki_id
@@ -71,4 +72,4 @@ class Image(BaseImage):
 
     def __str__(self):
         return "{0}@{1}: {2} ({3} {4} {5})".format(self.release, self.region, self.date, self.architecture,
-                                               self.instance_type, self.virtualization)
\ No newline at end of file
+                                               self.instance_type, self.virtualization)
